
[![REUSE status](https://api.reuse.software/badge/github.com/UG4/plugin_Limex)](https://api.reuse.software/info/github.com/UG4/plugin_Limex)


# Limex #

**UG4-Plugin** linearly implicit time-stepping.

Copyright 2009-2017 Goethe Center for Scientific Computing, University Frankfurt

Please install/clone this repository through UG4's package manager
[ughub](https://github.com/UG4/ughub).
